@@ -1,10 +1,9 @@
-/* $Id: nlOptimizer.c,v 1.3 2000/07/03 18:22:49 bates Exp $
-
+/*
    Implementation of eval_model() and spread() for R.
 
    Copyright 1999 Saikat DebRoy <saikat@stat.wisc.edu>
 
-   This file is part of the nlme library for S and related languages
+   This file is part of the nlme package for S and related languages
    and is made available under the terms of the GNU General Public
    License, version 2, or at your option, any later version,
    incorporated herein by reference.
@@ -15,11 +14,10 @@
    PURPOSE.  See the GNU General Public License for more
    details.
 
-   You should have received a copy of the GNU General Public
-   License along with this program; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-   MA 02111-1307, USA
- 
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, a copy is available at
+   http://www.r-project.org/Licenses/
+
 */
 
 #include "nlOptimizer.h"
